==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/fr_fr/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.!success.ticket_created'] = 'Le ticket #%1$s a été ouvert avec succès.';
$lang['AdminTickets.!success.ticket_updated'] = 'Le ticket #%1$s a été mis à jour avec succès.';
$lang['AdminTickets.!success.ticket_split'] = 'Le ticket #%1$s a été divisé avec succès en ticket #%2$s.';
$lang['AdminTickets.!success.ticket_merge'] = 'Les tickets sélectionnés ont été fusionnés avec succès dans le ticket #%1$s.';
$lang['AdminTickets.!success.ticket_reassign'] = 'Les tickets sélectionnés ont été réaffectés avec succès.';
$lang['AdminTickets.!success.ticket_update_status'] = 'Les tickets sélectionnés ont été mis à jour avec succès.';
$lang['AdminTickets.!success.ticket_delete'] = 'Les tickets sélectionnés ont été supprimés avec succès.';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Aucun membre du personnel et/ou département n\'a encore été créé. Cliquez sur %1$s ci-dessus pour créer un département, ou %2$s pour assigner un membre du personnel.';
$lang['AdminTickets.index.page_title'] = 'Gestionnaire de support > Tickets';
$lang['AdminTickets.add.page_title'] = 'Support Manager > Ouvrir un ticket';
$lang['AdminTickets.reply.page_title'] = 'Support Manager > Ticket #%1$s';
$lang['AdminTickets.search.page_title'] = 'Résultats de la recherche pour "%1$s"';
$lang['AdminTickets.text.unassigned'] = 'Non attribué';
$lang['AdminTickets.index.category_open'] = 'En attente de la réponse du personnel';
$lang['AdminTickets.index.category_awaiting_reply'] = 'En attente de la réponse du client';
$lang['AdminTickets.index.category_in_progress'] = 'En cours';
$lang['AdminTickets.index.category_on_hold'] = 'En attente';
$lang['AdminTickets.index.category_closed'] = 'Fermé';
$lang['AdminTickets.index.category_trash'] = 'Poubelle';
$lang['AdminTickets.index.categorylink_createticket'] = 'Billet ouvert';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Billets';
$lang['AdminTickets.index.heading_code'] = 'Numéro du billet';
$lang['AdminTickets.index.heading_client'] = 'Client';
$lang['AdminTickets.index.heading_priority'] = 'Priorité';
$lang['AdminTickets.index.heading_department_name'] = 'Département';
$lang['AdminTickets.index.heading_summary'] = 'Résumé';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Affecté à';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Dernière réponse';
$lang['AdminTickets.index.any'] = 'Tous';
$lang['AdminTickets.index.minutes'] = '%1$s minutes';
$lang['AdminTickets.index.hour'] = '1 heure';
$lang['AdminTickets.index.hours'] = '%1$s heures';
$lang['AdminTickets.index.field_ticket_number'] = 'Numéro du billet';
$lang['AdminTickets.index.field_priority'] = 'Priorité';
$lang['AdminTickets.index.field_department_id'] = 'Département';
$lang['AdminTickets.index.field_summary'] = 'Résumé';
$lang['AdminTickets.index.field_assigned_staff'] = 'Affecté à';
$lang['AdminTickets.index.field_last_reply'] = 'Dernière réponse';
$lang['AdminTickets.index.unassigned'] = 'Non attribué';
$lang['AdminTickets.index.last_reply_by'] = 'par';
$lang['AdminTickets.index.no_results'] = 'Il n\'y a actuellement aucun ticket avec ce statut.';
$lang['AdminTickets.index.text_with_selected'] = 'Avec une sélection de billets :';
$lang['AdminTickets.index.text_into_ticket'] = 'Ento ticket :';
$lang['AdminTickets.index.text_to_client'] = 'Au client :';
$lang['AdminTickets.index.text_to_status'] = 'Modifier en :';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Numéro du billet';
$lang['AdminTickets.index.text_no_tickets'] = 'Aucun billet ouvert n\'a été trouvé. Essayez de chercher à nouveau.';
$lang['AdminTickets.index.field_actionsubmit'] = 'Soumettre';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.add.boxtitle_add'] = 'Billet ouvert';
$lang['AdminTickets.add.heading_search_client'] = 'Recherche du client';
$lang['AdminTickets.add.text_no_clients'] = 'Aucun client n\'a été trouvé. Essayez de chercher à nouveau.';
$lang['AdminTickets.add.heading_summary'] = 'Résumé';
$lang['AdminTickets.add.heading_client'] = 'Client';
$lang['AdminTickets.add.heading_department'] = 'Département';
$lang['AdminTickets.add.heading_staff_id'] = 'Affecté à';
$lang['AdminTickets.add.heading_priority'] = 'Priorité';
$lang['AdminTickets.add.heading_status'] = 'Statut';
$lang['AdminTickets.add.field_attachments'] = 'Pièces jointes';
$lang['AdminTickets.add.field_details'] = 'Détails';
$lang['AdminTickets.add.text_add_attachment'] = 'Ajouter une pièce jointe';
$lang['AdminTickets.add.field_addsubmit'] = 'Billet ouvert';
$lang['Admintickets.add.client_placeholder'] = 'ID ou nom du client';
$lang['AdminTickets.add.text_add_response'] = 'Insérer une réponse prédéfinie';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Déposez les fichiers ici pour les télécharger ou cliquez pour sélectionner les fichiers.';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Supprimer le fichier';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Ticket #%1$s';
$lang['AdminTickets.reply.heading_summary'] = 'Résumé';
$lang['AdminTickets.reply.heading_client'] = 'Client';
$lang['AdminTickets.reply.heading_department'] = 'Département';
$lang['AdminTickets.reply.heading_staff_id'] = 'Affecté à';
$lang['AdminTickets.reply.heading_priority'] = 'Priorité';
$lang['AdminTickets.reply.heading_status'] = 'Statut';
$lang['AdminTickets.reply.heading_date_added'] = 'Date d\'ouverture';
$lang['AdminTickets.reply.text_add_response'] = 'Insérer une réponse prédéfinie';
$lang['AdminTickets.reply.text_with_selected'] = 'Avec des réponses sélectionnées, effectuer :';
$lang['AdminTickets.reply.heading_reply'] = 'Ajouter une réponse';
$lang['AdminTickets.reply.field_reply'] = 'Répondre';
$lang['AdminTickets.reply.field_note'] = 'Note';
$lang['AdminTickets.reply.field_attachments'] = 'Pièces jointes';
$lang['AdminTickets.reply.text_add_attachment'] = 'Ajouter une pièce jointe';
$lang['AdminTickets.reply.field_replysubmit'] = 'Ticket de mise à jour';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Aller';
$lang['AdminTickets.reply.refresh'] = 'Il y a de nouvelles réponses ou des changements de statut.';
$lang['AdminTickets.reply.refresh_link'] = 'Cliquez sur pour afficher.';
$lang['AdminTickets.reply.reply_date'] = 'Le %1$s %2$s %3$s a répondu';
$lang['AdminTickets.reply.log_date'] = '%1$s par %2$s %3$s';
$lang['AdminTickets.reply.system'] = 'Système';
$lang['AdminTickets.reply.staff_title'] = 'Personnel d\'appui';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Déposez les fichiers ici pour les télécharger ou cliquez pour sélectionner les fichiers.';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Supprimer le fichier';
$lang['AdminTickets.client.category_open'] = 'En attente de la réponse du personnel';
$lang['AdminTickets.client.category_awaiting_reply'] = 'En attente de la réponse du client';
$lang['AdminTickets.client.category_in_progress'] = 'En cours';
$lang['AdminTickets.client.category_on_hold'] = 'En attente';
$lang['AdminTickets.client.category_closed'] = 'Fermé';
$lang['AdminTickets.client.category_trash'] = 'Poubelle';
$lang['AdminTickets.client.categorylink_createticket'] = 'Billet ouvert';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Billets';
$lang['AdminTickets.client.heading_code'] = 'Numéro du billet';
$lang['AdminTickets.client.heading_priority'] = 'Priorité';
$lang['AdminTickets.client.heading_department_name'] = 'Département';
$lang['AdminTickets.client.heading_summary'] = 'Résumé';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Dernière réponse';
$lang['AdminTickets.client.no_results'] = 'Il n\'y a actuellement aucun ticket avec ce statut.';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Recherche de billets pour "%1$s"';
$lang['AdminTickets.search.heading_code'] = 'Numéro du billet';
$lang['AdminTickets.search.heading_priority'] = 'Priorité';
$lang['AdminTickets.search.heading_status'] = 'Statut';
$lang['AdminTickets.search.heading_department_name'] = 'Département';
$lang['AdminTickets.search.heading_summary'] = 'Résumé';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Dernière réponse';
$lang['AdminTickets.search.no_results'] = 'Aucun billet ne correspond aux critères de recherche.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/fr_fr/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.!success.ticket_created'] = 'Le ticket #%1$s a été ouvert avec succès.';
$lang['AdminTickets.!success.ticket_updated'] = 'Le ticket #%1$s a été mis à jour avec succès.';
$lang['AdminTickets.!success.ticket_split'] = 'Le ticket #%1$s a été divisé avec succès en ticket #%2$s.';
$lang['AdminTickets.!success.ticket_merge'] = 'Les tickets sélectionnés ont été fusionnés avec succès dans le ticket #%1$s.';
$lang['AdminTickets.!success.ticket_reassign'] = 'Les tickets sélectionnés ont été réaffectés avec succès.';
$lang['AdminTickets.!success.ticket_update_status'] = 'Les tickets sélectionnés ont été mis à jour avec succès.';
$lang['AdminTickets.!success.ticket_delete'] = 'Les tickets sélectionnés ont été supprimés avec succès.';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Aucun membre du personnel et/ou département n\'a encore été créé. Cliquez sur %1$s ci-dessus pour créer un département, ou %2$s pour assigner un membre du personnel.';
$lang['AdminTickets.index.page_title'] = 'Gestionnaire de support > Tickets';
$lang['AdminTickets.add.page_title'] = 'Support Manager > Ouvrir un ticket';
$lang['AdminTickets.reply.page_title'] = 'Support Manager > Ticket #%1$s';
$lang['AdminTickets.search.page_title'] = 'Résultats de la recherche pour "%1$s"';
$lang['AdminTickets.text.unassigned'] = 'Non attribué';
$lang['AdminTickets.index.category_open'] = 'En attente de la réponse du personnel';
$lang['AdminTickets.index.category_awaiting_reply'] = 'En attente de la réponse du client';
$lang['AdminTickets.index.category_in_progress'] = 'En cours';
$lang['AdminTickets.index.category_on_hold'] = 'En attente';
$lang['AdminTickets.index.category_closed'] = 'Fermé';
$lang['AdminTickets.index.category_trash'] = 'Poubelle';
$lang['AdminTickets.index.categorylink_createticket'] = 'Billet ouvert';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Billets';
$lang['AdminTickets.index.heading_code'] = 'Numéro du billet';
$lang['AdminTickets.index.heading_client'] = 'Client';
$lang['AdminTickets.index.heading_priority'] = 'Priorité';
$lang['AdminTickets.index.heading_department_name'] = 'Département';
$lang['AdminTickets.index.heading_summary'] = 'Résumé';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Affecté à';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Dernière réponse';
$lang['AdminTickets.index.any'] = 'Tous';
$lang['AdminTickets.index.minutes'] = '%1$s minutes';
$lang['AdminTickets.index.hour'] = '1 heure';
$lang['AdminTickets.index.hours'] = '%1$s heures';
$lang['AdminTickets.index.field_ticket_number'] = 'Numéro du billet';
$lang['AdminTickets.index.field_priority'] = 'Priorité';
$lang['AdminTickets.index.field_department_id'] = 'Département';
$lang['AdminTickets.index.field_summary'] = 'Résumé';
$lang['AdminTickets.index.field_assigned_staff'] = 'Affecté à';
$lang['AdminTickets.index.field_last_reply'] = 'Dernière réponse';
$lang['AdminTickets.index.unassigned'] = 'Non attribué';
$lang['AdminTickets.index.last_reply_by'] = 'par';
$lang['AdminTickets.index.no_results'] = 'Il n\'y a actuellement aucun ticket avec ce statut.';
$lang['AdminTickets.index.text_with_selected'] = 'Avec une sélection de billets :';
$lang['AdminTickets.index.text_into_ticket'] = 'Ento ticket :';
$lang['AdminTickets.index.text_to_client'] = 'Au client :';
$lang['AdminTickets.index.text_to_status'] = 'Modifier en :';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Numéro du billet';
$lang['AdminTickets.index.text_no_tickets'] = 'Aucun billet ouvert n\'a été trouvé. Essayez de chercher à nouveau.';
$lang['AdminTickets.index.field_actionsubmit'] = 'Soumettre';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.add.boxtitle_add'] = 'Billet ouvert';
$lang['AdminTickets.add.heading_search_client'] = 'Recherche du client';
$lang['AdminTickets.add.text_no_clients'] = 'Aucun client n\'a été trouvé. Essayez de chercher à nouveau.';
$lang['AdminTickets.add.heading_summary'] = 'Résumé';
$lang['AdminTickets.add.heading_client'] = 'Client';
$lang['AdminTickets.add.heading_department'] = 'Département';
$lang['AdminTickets.add.heading_staff_id'] = 'Affecté à';
$lang['AdminTickets.add.heading_priority'] = 'Priorité';
$lang['AdminTickets.add.heading_status'] = 'Statut';
$lang['AdminTickets.add.field_attachments'] = 'Pièces jointes';
$lang['AdminTickets.add.field_details'] = 'Détails';
$lang['AdminTickets.add.text_add_attachment'] = 'Ajouter une pièce jointe';
$lang['AdminTickets.add.field_addsubmit'] = 'Billet ouvert';
$lang['Admintickets.add.client_placeholder'] = 'ID ou nom du client';
$lang['AdminTickets.add.text_add_response'] = 'Insérer une réponse prédéfinie';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Déposez les fichiers ici pour les télécharger ou cliquez pour sélectionner les fichiers.';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Supprimer le fichier';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Ticket #%1$s';
$lang['AdminTickets.reply.heading_summary'] = 'Résumé';
$lang['AdminTickets.reply.heading_client'] = 'Client';
$lang['AdminTickets.reply.heading_department'] = 'Département';
$lang['AdminTickets.reply.heading_staff_id'] = 'Affecté à';
$lang['AdminTickets.reply.heading_priority'] = 'Priorité';
$lang['AdminTickets.reply.heading_status'] = 'Statut';
$lang['AdminTickets.reply.heading_date_added'] = 'Date d\'ouverture';
$lang['AdminTickets.reply.text_add_response'] = 'Insérer une réponse prédéfinie';
$lang['AdminTickets.reply.text_with_selected'] = 'Avec des réponses sélectionnées, effectuer :';
$lang['AdminTickets.reply.heading_reply'] = 'Ajouter une réponse';
$lang['AdminTickets.reply.field_reply'] = 'Répondre';
$lang['AdminTickets.reply.field_note'] = 'Note';
$lang['AdminTickets.reply.field_attachments'] = 'Pièces jointes';
$lang['AdminTickets.reply.text_add_attachment'] = 'Ajouter une pièce jointe';
$lang['AdminTickets.reply.field_replysubmit'] = 'Ticket de mise à jour';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Aller';
$lang['AdminTickets.reply.refresh'] = 'Il y a de nouvelles réponses ou des changements de statut.';
$lang['AdminTickets.reply.refresh_link'] = 'Cliquez sur pour afficher.';
$lang['AdminTickets.reply.reply_date'] = 'Le %1$s %2$s %3$s a répondu';
$lang['AdminTickets.reply.log_date'] = '%1$s par %2$s %3$s';
$lang['AdminTickets.reply.system'] = 'Système';
$lang['AdminTickets.reply.staff_title'] = 'Personnel d\'appui';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Déposez les fichiers ici pour les télécharger ou cliquez pour sélectionner les fichiers.';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Supprimer le fichier';
$lang['AdminTickets.client.category_open'] = 'En attente de la réponse du personnel';
$lang['AdminTickets.client.category_awaiting_reply'] = 'En attente de la réponse du client';
$lang['AdminTickets.client.category_in_progress'] = 'En cours';
$lang['AdminTickets.client.category_on_hold'] = 'En attente';
$lang['AdminTickets.client.category_closed'] = 'Fermé';
$lang['AdminTickets.client.category_trash'] = 'Poubelle';
$lang['AdminTickets.client.categorylink_createticket'] = 'Billet ouvert';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Billets';
$lang['AdminTickets.client.heading_code'] = 'Numéro du billet';
$lang['AdminTickets.client.heading_priority'] = 'Priorité';
$lang['AdminTickets.client.heading_department_name'] = 'Département';
$lang['AdminTickets.client.heading_summary'] = 'Résumé';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Dernière réponse';
$lang['AdminTickets.client.no_results'] = 'Il n\'y a actuellement aucun ticket avec ce statut.';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Recherche de billets pour "%1$s"';
$lang['AdminTickets.search.heading_code'] = 'Numéro du billet';
$lang['AdminTickets.search.heading_priority'] = 'Priorité';
$lang['AdminTickets.search.heading_status'] = 'Statut';
$lang['AdminTickets.search.heading_department_name'] = 'Département';
$lang['AdminTickets.search.heading_summary'] = 'Résumé';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Dernière réponse';
$lang['AdminTickets.search.no_results'] = 'Aucun billet ne correspond aux critères de recherche.';
$lang['AdminTickets.reply.text_contacts'] = 'Les contacts non sélectionnés seront automatiquement ajoutés au ticket s\'ils y répondent.';
$lang['AdminTickets.reply.text_add_recipient'] = 'Ajouter un destinataire';
$lang['AdminTickets.reply.heading_contacts'] = 'Contacts';
$lang['AdminTickets.reply.heading_recipients'] = 'Bénéficiaires';
$lang['AdminTickets.add.text_contacts'] = 'Les contacts non sélectionnés seront automatiquement ajoutés au ticket s\'ils y répondent.';
$lang['AdminTickets.add.text_add_recipient'] = 'Ajouter un destinataire';
$lang['AdminTickets.add.heading_contacts'] = 'Contacts';
$lang['AdminTickets.add.heading_recipients'] = 'Bénéficiaires';
